@@ -57,40 +57,52 @@ class Client:
             return Client.error_result(self, e=e, fname="get_markets", response=self.response_ramzinex)
 
     def get_markets_turnover(self):
-        data = Client.get_markets()
-        if data is not None:
-            try:
-                pairs_volume, usdt_pairs_volume, irr_pairs_volume = [], [], []
-                for market in data["data"]:
-                    try:
-                        pair_dict = {"pair": market['tv_symbol']['ramzinex'],
-                                     "quote_volume": str(market["financial"]["last24h"]['quote_volume']),
-                                     "base_volume": str(market["financial"]["last24h"]['base_volume']),
-                                     "date_time": datetime.now().strftime("%Y-%m-%d %H:%M:%S")}
-                        pairs_volume.append(pair_dict)
-                        if market['tv_symbol']['ramzinex'][-3:] == "irr":
-                            irr_pairs_volume.append(pair_dict)
-                        elif market['tv_symbol']['ramzinex'][-4:] == "usdt":
-                            usdt_pairs_volume.append(pair_dict)
-                    except Exception as e:
-                        logger.exception(str(e))
+        gmarkets = Client.get_markets(self)
+        pairs_volume, usdt_pairs_volume, irr_pairs_volume = [], [], []
+        tether_price = 0
+        try:
+            for market in gmarkets["data"]:
+                try:
+                    pair_dict = {"pair": market['tv_symbol']['ramzinex'],
+                                 "base_currency_symbol": market['base_currency_symbol']["en"],
+                                 "quote_currency_symbol": market['quote_currency_symbol']["en"],
+                                 "quote_volume": str(market["financial"]["last24h"]['quote_volume']),
+                                 "base_volume": str(market["financial"]["last24h"]['base_volume']),
+                                 "date_time": datetime.now().strftime("%Y-%m-%d %H:%M:%S")}
+                    pairs_volume.append(pair_dict)
+                    if market['tv_symbol']['ramzinex'] == "usdtirr":
+                        tether_price = market['sell']
+                except Exception as e:
+                    return Client.error_result(self, e=e, fname="get_markets_turnover")
 
-                # df = pd.DataFrame(pairs_volume)
-                df_irr = pd.DataFrame(irr_pairs_volume)
-                irr_markets_turnover = df_irr[['quote_volume']].astype(float).sum()['quote_volume']
-                df_usdt = pd.DataFrame(usdt_pairs_volume)
-                usdt_markets_turnover = df_usdt[['quote_volume']].astype(float).sum()['quote_volume']
+            df = pd.DataFrame(pairs_volume)
+            df_irr = df[df["quote_currency_symbol"] == "irr"]
+            df_usdt = df[df["quote_currency_symbol"] == "usdt"]
 
-                result_data = {"irr_markets_turnover": irr_markets_turnover,
-                               "usdt_markets_turnover": usdt_markets_turnover,
-                               "pairs_volume": pairs_volume,
-                               "irr_pairs_volume": irr_pairs_volume,
-                               "usdt_pairs_volume": usdt_pairs_volume
-                               }
-                result = {"status": 0, "message": "ok", "data": result_data}
-                return result
-            except Exception as e:
-                return Client.error_result(self, e=e, fname="get_markets_turnover")
+            irr_markets_turnover = df_irr[['quote_volume']].astype(float).sum()['quote_volume']
+            usdt_markets_turnover = df_usdt[['quote_volume']].astype(float).sum()['quote_volume']
+
+            df_irru = df_irr[df_irr['currency'].isin(df_usdt['currency'])]
+            df_irru = df_irru.reset_index(drop=True)
+
+            iu_markets_turnover = df_irru[['quote_volume']].astype(float).sum()['quote_volume']
+            percent = 100 * (usdt_markets_turnover * tether_price) / irr_markets_turnover
+            percent_iu = 100 * (usdt_markets_turnover * tether_price) / iu_markets_turnover
+
+            result_data = {"irr_MT": irr_markets_turnover,
+                           "usdt_MT": usdt_markets_turnover,
+                           "common_irrusdt_MT": iu_markets_turnover,
+                           "percent": percent,
+                           "common_irrusdt_percent": percent_iu,
+                           "tether_price": tether_price,
+                           "datetime": datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
+                           "pairs_volume": pairs_volume,
+                           }
+            
+            result = {"status": 0, "message": "ok", "data": result_data}
+            return result
+        except Exception as e:
+            return Client.error_result(self, e=e, fname="get_markets_turnover")
 
     def get_orderbook(self, pair_id, side):  # get ramzinex orderbook for pair
         print(self)
@@ -173,7 +185,7 @@ class Client:
     def get_balance(self):  # check ramzinex balance
         try:
             url = "https://ramzinex.com/exchange/api/v1.0/exchange/users/me/funds/details"
-            headers = {'Content-Type': 'application/json','Authorization': 'Bearer {}'.format(self.api)}
+            headers = {'Content-Type': 'application/json', 'Authorization': 'Bearer {}'.format(self.api)}
             response_ramzinex = self.scraper.get(url=url, headers=headers)
             check_response_ramzinex = json.loads(response_ramzinex.text)
             return check_response_ramzinex
